結果
| 問題 | No.279 木の数え上げ |
| コンテスト | |
| ユーザー |
maspy
|
| 提出日時 | 2020-01-11 11:25:47 |
| 言語 | Python3 (3.15.0 + numpy 2.5.4 + scipy 1.18.1 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 65 ms / 2,000 ms |
| + 429µs | |
| コード長 | 285 bytes |
| 記録 | |
| コンパイル時間 | 172 ms |
| コンパイル使用メモリ | 15,104 KB |
| 実行使用メモリ | 12,756 KB |
| 最終ジャッジ日時 | 2026-09-29 05:22:57 |
| 合計ジャッジ時間 | 2,941 ms |
|
ジャッジサーバーID (参考情報) |
judge3_0 / judge4_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| other | AC * 21 |
ソースコード
import sys read = sys.stdin.buffer.read readline = sys.stdin.buffer.readline readlines = sys.stdin.buffer.readlines from collections import Counter S = read().rstrip().decode() counter = Counter(S) t,r,e = [counter[x] for x in 'tre'] ee = e // 2 answer = min(t,r,ee) print(answer)
maspy